@@ -1,6 +1,6 @@
 package WWW::Google::UserAgent::DataTypes;
 
-$WWW::Google::UserAgent::DataTypes::VERSION = '0.08';
+$WWW::Google::UserAgent::DataTypes::VERSION = '0.09';
 
 use 5.006;
 use parent 'Exporter';
@@ -18,7 +18,7 @@ WWW::Google::UserAgent::DataTypes - Used by the core library WWW::Google::UserAg
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
@@ -48,6 +48,10 @@ our $XmlOrJson = sub {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-UserAgent>
+
 =head1 BUGS
 
 Please  report  any  bugs  or  feature  requests to C<bug-www-google-useragent at
